package geo.profile.view;

import geo.profile.Perfil;
import geo.profile.R;
import android.app.Activity;
import android.app.AlertDialog;
import android.app.Dialog;
import android.content.DialogInterface;
import android.content.DialogInterface.OnClickListener;
import android.os.Bundle;
import android.text.Editable;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.AdapterView.OnItemClickListener;
import android.widget.ArrayAdapter;
import android.widget.EditText;
import android.widget.ListView;
import android.widget.Spinner;
import android.widget.TextView;
import android.widget.Toast;

public class DesvioActivity extends Activity {
	
	Integer idPerfil;
	Perfil perfil;
	String [] desvio;
	
	ListView listaDesvio;
	
	//Declaramos todo lo necesario para el desvio de llamadas
	private Desvio[] datos = new Desvio[4];
	private static final int DIALOGO_SIEMPRE = 1;
	private static final int DIALOGO_OCUPADA = 2;
	private static final int DIALOGO_SIN_RESPUESTA = 3;
	private static final int DIALOGO_SIN_CONEXION = 4;
	boolean [] array_habilitado = new boolean[4];
	String [] array_telefonos = new String[4];
	Editable telefono;
	String retraso;
	
    /** Called when the activity is first created. */
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.desvio);
        
        //Obtenemos el id (extra en el intent)
        Bundle bun = this.getIntent().getExtras();
        idPerfil = bun.getInt("id");
        
        //Obtenemos los datos de Desvio de la BD
        perfil = new Perfil();
    	perfil.loadPerfil(DesvioActivity.this,idPerfil);
    	desvio = perfil.buscarDesvio(this);
        
        datos[0] = new Desvio("Desviar siempre");
        datos[1] = new Desvio("Lnea ocupada");
        datos[2] = new Desvio("Llamada sin respuesta");
        datos[3] = new Desvio("No se establece la llamada");
          
        AdaptadorDesvio adaptador = new AdaptadorDesvio(this);
        
        listaDesvio = (ListView)findViewById(R.id.ListaDesvio);
        
        listaDesvio.setAdapter(adaptador);
        
        //Lanzamos los dialogos segun el caso
        
        listaDesvio.setOnItemClickListener(new OnItemClickListener() {
		    public void onItemClick(AdapterView<?> a, View v, int position, long id) {
		    	if(position == 0){	//Desviar siempre
		    		showDialog(DIALOGO_SIEMPRE);
		    	}else if(position == 1){	//Linea ocupada
		    		showDialog(DIALOGO_OCUPADA);
		    	}else if(position == 2){	//Llamada sin respuesta
		    		showDialog(DIALOGO_SIN_RESPUESTA);
		    	}else if(position == 3){	//No se establece la llamada
		    		showDialog(DIALOGO_SIN_CONEXION);
		    	}
		    }
    	});
    }
    
    class AdaptadorDesvio extends ArrayAdapter<Desvio> {
    	
    	Activity context;
    	
    	AdaptadorDesvio(Activity context) {
    		super(context, R.layout.desvio_fila, datos);
    		this.context = context;
    	}
    	
    	@Override
		public View getView(int position, View convertView, ViewGroup parent) 
    	{
			View item = convertView;
			ViewHolder holder;
    		
    		if(item == null)
    		{
    			LayoutInflater inflater = context.getLayoutInflater();
    			item = inflater.inflate(R.layout.desvio_fila, null);
    			
    			holder = new ViewHolder();
    			holder.cuandoDesviar = (TextView)item.findViewById(R.id.LblCuandoDesviar);
    			holder.habilitado = (TextView)item.findViewById(R.id.LblHabilitado);
    			
    			item.setTag(holder);
    		}
    		else
    		{
    			holder = (ViewHolder)item.getTag();
    		}
			
			holder.cuandoDesviar.setText(datos[position].getCuandoDesviar());
			holder.habilitado.setText(datos[position].getHabilitado());
			
			return(item);
		}
    }
    
    static class ViewHolder{
    	TextView cuandoDesviar;
    	TextView habilitado;
    }
    
    public class Desvio{
    	private String cuandoDesviar;
    	private String habilitado;
    	
    	public Desvio(String cndDes){
    		cuandoDesviar = cndDes;
    	}

    	public Desvio(String cndDes, String hab){
    		cuandoDesviar = cndDes;
    		habilitado = hab;
    	}
    	
    	public String getCuandoDesviar(){
    		return cuandoDesviar;
    	}
    	
    	public String getHabilitado(){
    		return habilitado;
    	}
    	
    	public void setHabilitado(String hab){
    		habilitado = hab;
    	}
    }
    
    @Override
    protected Dialog onCreateDialog(int id) {
    	Dialog dialogo = null;

    	switch(id)
    	{
    		case DIALOGO_SIEMPRE:
    			dialogo = crearDialogoSiempre();
    			break;
    		case DIALOGO_OCUPADA:
    			dialogo = crearDialogoOcupada();
    			break;
    		case DIALOGO_SIN_RESPUESTA:
    			dialogo = crearDialogoSinRespuesta();
    			break;
    		case DIALOGO_SIN_CONEXION:
    			dialogo = crearDialogoSinConexion();
    			break;
    		default:
    			dialogo = null;
    			break;
    	}
    
    	return dialogo;
    }
    
    private Dialog crearDialogoSiempre()
    {
    	AlertDialog.Builder builder = new AlertDialog.Builder(this);
    	
    	LayoutInflater inflater = (LayoutInflater) this.getSystemService(LAYOUT_INFLATER_SERVICE);
    	View layout = inflater.inflate(R.layout.dialogo_desvio_siempre_ocupada_sinconexion,null);

    	builder.setTitle("Desviar siempre");
    	builder.setMessage("Utilizar siempre este nmero");
    	builder.setView(layout);
    	EditText edtNumeroTelefono = (EditText)layout.findViewById(R.id.EdtNumeroTelefono);
    	edtNumeroTelefono.setText(desvio[1]);
    	telefono = edtNumeroTelefono.getText();
    	builder.setPositiveButton("Habilitar", new OnClickListener() {
			public void onClick(DialogInterface dialog, int which) {
				array_habilitado [0] = true;
				array_telefonos[0] = telefono.toString();
				guardarDesvio(DIALOGO_SIEMPRE,array_habilitado[0],array_telefonos[0],null);
				Toast t = Toast.makeText(DesvioActivity.this, "Se ha habilitado el desvo \"Siempre\". " +
						"Se activar cuando su localizacin o franja horaria coincidan con las " +
						"configuradas en el perfil.", Toast.LENGTH_LONG);
				t.show();
			}
		});
    	builder.setNegativeButton("Deshabilitar", new OnClickListener() {
			public void onClick(DialogInterface dialog, int which) {
				array_habilitado [0] = false;
				array_telefonos[0] = "";
				guardarDesvio(DIALOGO_SIEMPRE,array_habilitado[0],array_telefonos[0],null);
				Toast t = Toast.makeText(DesvioActivity.this, "Se ha deshabilitado el desvo \"Siempre\".", Toast.LENGTH_SHORT);
				t.show();
				dialog.cancel();
			}
		});
    	
    	
    	
    	return builder.create();
    }
    
    private Dialog crearDialogoOcupada()
    {
    	AlertDialog.Builder builder = new AlertDialog.Builder(this);
    	
    	LayoutInflater inflater = (LayoutInflater) this.getSystemService(LAYOUT_INFLATER_SERVICE);
    	View layout = inflater.inflate(R.layout.dialogo_desvio_siempre_ocupada_sinconexion,null);
    	
    	builder.setTitle("Lnea ocupada");
    	builder.setMessage("Nmero cuando la lnea est ocupada");
    	builder.setView(layout);
    	EditText edtNumeroTelefono = (EditText)layout.findViewById(R.id.EdtNumeroTelefono);
    	if(Integer.parseInt(desvio[2]) == 1){
    		edtNumeroTelefono.setText(desvio[3]);
    	}
    	telefono = edtNumeroTelefono.getText();
    	builder.setPositiveButton("Habilitar", new OnClickListener() {
			public void onClick(DialogInterface dialog, int which) {
				array_habilitado [1] = true;
				array_telefonos[1] = telefono.toString();
				guardarDesvio(DIALOGO_OCUPADA,array_habilitado[1],array_telefonos[1],null);
				Toast t = Toast.makeText(DesvioActivity.this, "Se ha habilitado el desvo \"Lnea ocupada\". " +
						"Se activar cuando su localizacin o franja horaria coincidan con las configuradas" +
						" en el perfil.",Toast.LENGTH_LONG);
				t.show();
			}
		});
    	builder.setNegativeButton("Deshabilitar", new OnClickListener() {
			public void onClick(DialogInterface dialog, int which) {
				array_habilitado [1] = false;
				array_telefonos[1] = "";
				guardarDesvio(DIALOGO_OCUPADA,array_habilitado[1],array_telefonos[1],null);
				Toast t = Toast.makeText(DesvioActivity.this, "Se ha deshabilitado el desvo \"Lnea ocupada\".", Toast.LENGTH_SHORT);
				t.show();
				dialog.cancel();
			}
		});
    	
    	return builder.create();
    }
    
    private Dialog crearDialogoSinRespuesta()
    {
    	AlertDialog.Builder builder = new AlertDialog.Builder(this);
    	
    	LayoutInflater inflater = (LayoutInflater) this.getSystemService(LAYOUT_INFLATER_SERVICE);
    	View layout = inflater.inflate(R.layout.dialogo_desvio_sinrespuesta,null);
    	
    	//Componentes del dialogo
    	
    	builder.setTitle("Llamada sin respuesta");
    	builder.setMessage("Nmero cuando no se responde la llamada");
    	builder.setView(layout);
    	//Spinner Retraso
    	final String[] datos_retraso = new String[]{"5s", "10s", "15s", "20s", "25s", "30s"};
    	
    	ArrayAdapter<String> adaptador = new ArrayAdapter<String>(this,
    			android.R.layout.simple_spinner_item, datos_retraso);
    	
    	final Spinner spinnerRetraso = (Spinner)layout.findViewById(R.id.SpinnerRetraso);
    	 
    	adaptador.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
    	 
    	spinnerRetraso.setAdapter(adaptador);
    	
    	spinnerRetraso.setOnItemSelectedListener(
    	        new AdapterView.OnItemSelectedListener() {
    	        public void onItemSelected(AdapterView<?> parent,
    	            android.view.View v, int position, long id) {
    	        	retraso = datos_retraso[position];
    	        }
    	 
    	        public void onNothingSelected(AdapterView<?> parent) {
    	        	retraso = "5s";
    	        }
    	});
    	
    	EditText edtNumeroTelefono = (EditText)layout.findViewById(R.id.EdtNumeroTelefono);
    	if(Integer.parseInt(desvio[4]) == 1){
    		edtNumeroTelefono.setText(desvio[5]);
    	}
    	telefono = edtNumeroTelefono.getText();
    	
    	if(desvio[6] != null){
	    	if(desvio[6].equals("5")){
	    		spinnerRetraso.setSelection(0);
	    	}else if(desvio[6].equals("10")){
	    		spinnerRetraso.setSelection(1);
	    	}else if(desvio[6].equals("15")){
	    		spinnerRetraso.setSelection(2);
	    	}else if(desvio[6].equals("20")){
	    		spinnerRetraso.setSelection(3);
	    	}else if(desvio[6].equals("25")){
	    		spinnerRetraso.setSelection(4);
	    	}else if(desvio[6].equals("30")){
	    		spinnerRetraso.setSelection(5);
	    	}
    	}
    	
    	builder.setPositiveButton("Habilitar", new OnClickListener() {
			public void onClick(DialogInterface dialog, int which) {
				array_habilitado [2] = true;
				array_telefonos[2] = telefono.toString();
				guardarDesvio(DIALOGO_SIN_RESPUESTA,array_habilitado[2],array_telefonos[2],retraso);
				Toast t = Toast.makeText(DesvioActivity.this, "Se ha habilitado el desvo \"Sin respuesta\". " +
						"Se activar cuando su localizacin o franja horaria coincidan con las configuradas" +
						" en el perfil.", Toast.LENGTH_LONG);
				t.show();
			}
		});
    	builder.setNegativeButton("Deshabilitar", new OnClickListener() {
			public void onClick(DialogInterface dialog, int which) {
				array_habilitado [2] = false;
				array_telefonos[2] = "";
				guardarDesvio(DIALOGO_SIN_RESPUESTA,array_habilitado[2],array_telefonos[2],null);
				Toast t = Toast.makeText(DesvioActivity.this, "Se ha deshabilitado el desvo \"Sin respuesta\".", Toast.LENGTH_SHORT);
				t.show();
				dialog.cancel();
			}
		});
    	
    	return builder.create();
    }
    
    private Dialog crearDialogoSinConexion()
    {
    	AlertDialog.Builder builder = new AlertDialog.Builder(this);
    	
    	LayoutInflater inflater = (LayoutInflater) this.getSystemService(LAYOUT_INFLATER_SERVICE);
    	View layout = inflater.inflate(R.layout.dialogo_desvio_siempre_ocupada_sinconexion,null);
    	
    	builder.setTitle("No se establece la llamada");
    	builder.setMessage("Nmero cuando no sepuede establecer la llamada");
    	builder.setView(layout);
    	EditText edtNumeroTelefono = (EditText)layout.findViewById(R.id.EdtNumeroTelefono);
    	if(Integer.parseInt(desvio[7]) == 1){
    		edtNumeroTelefono.setText(desvio[8]);
    	}
    	telefono = edtNumeroTelefono.getText();
    	builder.setPositiveButton("Habilitar", new OnClickListener() {
			public void onClick(DialogInterface dialog, int which) {
				array_habilitado [3] = true;
				array_telefonos[3] = telefono.toString();
				guardarDesvio(DIALOGO_SIN_CONEXION,array_habilitado[3],array_telefonos[3],null);
				Toast t = Toast.makeText(DesvioActivity.this, "Se ha habilitado el desvo \"Sin conexin\". " +
						"Se activar cuando su localizacin o franja horaria coincidan con las configuradas" +
						" en el perfil.", Toast.LENGTH_LONG);
				t.show();
			}
		});
    	builder.setNegativeButton("Deshabilitar", new OnClickListener() {
			public void onClick(DialogInterface dialog, int which) {
				array_habilitado [3] = false;
				array_telefonos[3] = "";
				guardarDesvio(DIALOGO_SIN_CONEXION,array_habilitado[3],array_telefonos[3],null);
				Toast t = Toast.makeText(DesvioActivity.this, "Se ha deshabilitado el desvo \"Sin conexin\".", Toast.LENGTH_SHORT);
				t.show();
				dialog.cancel();
			}
		});
    	
    	return builder.create();
    }
    
    public void guardarDesvio(int tipo_desvio, boolean habilitado, String telefono, String retraso){
    	
    	perfil = new Perfil();
    	perfil.loadPerfil(DesvioActivity.this,idPerfil);
    	
    	int marcado = 0;
    	String retrasoSinS = null;
    	
    	if(habilitado){
    		marcado = 1;
    	}
    	
    	switch(tipo_desvio)
    	{
	  		case DIALOGO_SIEMPRE:
	  			perfil.setDesvioSiempre(marcado);
	  			perfil.setTelefonoSiempre(telefono);
	  			perfil.updatePerfilDesvioSiempre(this);
	  			break;
	  		case DIALOGO_OCUPADA:
	  			perfil.setDesvioOcupada(marcado);
	  			perfil.setTelefonoOcupada(telefono);
	  			perfil.updatePerfilDesvioOcupada(this);
	  			break;
	  		case DIALOGO_SIN_RESPUESTA:
	  			if(retraso != null){
	  				retrasoSinS = retraso.substring(0, retraso.length()-1);
	  			}
	  			perfil.setDesvioSinRespuesta(marcado);
	  			perfil.setTelefonoSinRespuesta(telefono);
	  			perfil.setRetraso(retrasoSinS);
	  			perfil.updatePerfilDesvioSinRespuesta(this);
	  			break;
	  		case DIALOGO_SIN_CONEXION:
	  			perfil.setDesvioSinConexion(marcado);
	  			perfil.setTelefonoSinConexion(telefono);
	  			perfil.updatePerfilDesvioSinConexion(this);
	  			break;
	  		default:
	  			break;
	  	}
    }
}